==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/attributes/AttributesOpParam.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.attributes;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.attributes.attributes.Top;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of attributes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class AttributesOpParam extends InnerModelObject implements Attributes {
    protected Top top;

    @Override
    public Top top() {
        return top;
    }

    @Override
    public void top(Top top) {
        this.top = top;
    }

    @Override
    public int hashCode() {
        return Objects.hash(top);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof AttributesOpParam) {
            AttributesOpParam other = (AttributesOpParam) obj;
            return
                Objects.equals(top, other.top);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("top=" + top)
            .toString();
    }

    /**
     * Creates an instance of attributesOpParam.
     */
    public AttributesOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/attributes/AttributesOpParam.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.attributes;

import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.attributes.attributes.Top;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of attributes.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class AttributesOpParam extends InnerModelObject implements Attributes {
    protected Top top;

    @Override
    public Top top() {
        return top;
    }

    @Override
    public void top(Top top) {
        this.top = top;
    }

    @Override
    public int hashCode() {
        return Objects.hash(top);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof AttributesOpParam) {
            AttributesOpParam other = (AttributesOpParam) obj;
            return
                Objects.deepEquals(top, other.top);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("top=" + top)
            .toString();
    }

    /**
     * Creates an instance of attributesOpParam.
     */
    public AttributesOpParam() {
    }


    @Override
    public void addAugmentation(InnerModelObject obj) {
    }

    @Override
    public void removeAugmentation(InnerModelObject obj) {
    }

    @Override
    public Map<Class<? extends InnerModelObject>, InnerModelObject> augmentations() {

        return null;
    }

    @Override
    public <T extends InnerModelObject> T augmentation(Class<T> c) {

        return null;
    }
}
